@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
+"""This module is used to launch EC2Stack.
+"""
+
 from werkzeug.serving import run_simple
 from werkzeug.wsgi import DispatcherMiddleware
 
