@@ -1,4 +1,7 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
+"""This module exposes all models.
+"""
+
 from ec2stack.models.users.models import *
