@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 # encoding: utf-8
 
+"""This module creates services for all models.
+"""
+
 from ec2stack.models.users import UsersService
 
 
